@@ -201,7 +201,7 @@ void QAptActions::setActionsEnabled(bool enabled)
 
     actionCollection()->action("undo")->setEnabled(m_backend && !m_backend->isUndoStackEmpty());
     actionCollection()->action("redo")->setEnabled(m_backend && !m_backend->isRedoStackEmpty());
-    actionCollection()->action("revert")->setEnabled(m_backend && !m_backend->isUndoStackEmpty());
+    actionCollection()->action("revert")->setEnabled(m_backend && m_backend->areChangesMarked());
     
     actionCollection()->action("save_download_list")->setEnabled(isConnected());
 
@@ -379,6 +379,7 @@ void QAptActions::redo()
 
 void QAptActions::revertChanges()
 {
+    m_backend->saveCacheState();
     m_backend->restoreCacheState(m_originalState);
     emit changesReverted();
 }
@@ -475,7 +476,7 @@ void QAptActions::showHistoryDialog()
         KWindowConfig::restoreWindowSize(m_historyDialog->windowHandle(), dialogConfig);
         
 
-        connect(m_historyDialog, SIGNAL(finished()), SLOT(closeHistoryDialog()));
+        connect(m_historyDialog, SIGNAL(finished(int)), SLOT(closeHistoryDialog()));
         HistoryView *historyView = new HistoryView(m_historyDialog);
         m_historyDialog->layout()->addWidget(historyView);
         m_historyDialog->setWindowTitle(i18nc("@title:window", "Package History"));
